@@ -1,13 +1,16 @@
+"""Factories used to create top level objects such as pods, sessions and charges"""
 from typing import Dict, Any, List
 from .pod import Pod
 from .schedule import Schedule, ScheduleStatus
 from .charge import Charge
 
 class PodFactory:
+    """Factory for creating Pod objects"""
     def build_pods(self, pods_response: Dict[str, Any]) -> List[Pod]:
+        """Build a number of pod objects based off of a response from pod point"""
         pods = []
 
-        pods_data = pods_response.get('pods', None) 
+        pods_data = pods_response.get('pods', None)
         if pods_data is None:
             return pods
 
@@ -17,11 +20,18 @@ class PodFactory:
         return pods
 
 class ScheduleFactory:
-    def build_schedules(self, enabled: bool, start_time: str = "00:00:00", end_time: str = "00:00:01") -> List[Schedule]:
+    """Factory for creating Schedule objects"""
+    def build_schedules(
+        self,
+        enabled: bool,
+        start_time: str = "00:00:00",
+        end_time: str = "00:00:01"
+    ) -> List[Schedule]:
+        """Build a number of schedule objects based off of a response from pod point"""
         schedules = []
 
-        for i in range(7):
-            day = i + 1
+        for iterator in range(7):
+            day = iterator + 1
 
             schedule = Schedule(
                 start_day=day,
@@ -37,10 +47,12 @@ class ScheduleFactory:
 
 
 class ChargeFactory:
+    """Factory  for creating Charge objects"""
     def build_charges(self, charge_response: Dict[str, Any]) -> List[Charge]:
+        """Build a list of charge objects based off of a response from pod point"""
         charges = []
 
-        charge_data = charge_response.get('charges', None) 
+        charge_data = charge_response.get('charges', None)
         if charge_data is None:
             return charges
 
